import 'package:meta/meta.dart';

@immutable
class OpenAIEditModelChoice {
  /// The text of the choice.
  final String text;

  /// The index of the choice.
  final int index;

  @override
  int get hashCode => text.hashCode ^ index.hashCode;

  /// This class is used to represent a choice generated by an OpenAI edit.
  const OpenAIEditModelChoice({
    required this.text,
    required this.index,
  });

  /// This method is used to convert a [Map<String, dynamic>] object to a [OpenAIEditModelChoice] object.
  factory OpenAIEditModelChoice.fromMap(Map<String, dynamic> json) {
    return OpenAIEditModelChoice(
      text: json['text'],
      index: json['index'],
    );
  }

  @override
  bool operator ==(covariant OpenAIEditModelChoice other) {
    if (identical(this, other)) return true;

    return other.text == text && other.index == index;
  }

  @override
  String toString() => 'OpenAIEditModelChoice(text: $text, index: $index)';
}
